@@ -1,7 +1,7 @@
 import json
 import os
 from json.decoder import JSONDecodeError
-from typing import Optional
+from typing import Dict, List, Optional
 from urllib.error import HTTPError, URLError
 
 import click  # type: ignore
@@ -25,6 +25,7 @@ class StacValidate:
 
     Attributes:
         stac_file (str): The path or URL to the STAC object to be validated.
+        collections (bool): Validate response from a /collections endpoint.
         item_collection (bool): Whether the STAC object to be validated is an item collection.
         pages (int): The maximum number of pages to validate if `item_collection` is True.
         recursive (bool): Whether to recursively validate related STAC objects.
@@ -45,6 +46,7 @@ class StacValidate:
     def __init__(
         self,
         stac_file: Optional[str] = None,
+        collections: bool = False,
         item_collection: bool = False,
         pages: Optional[int] = None,
         recursive: bool = False,
@@ -58,9 +60,10 @@ class StacValidate:
         log: str = "",
     ):
         self.stac_file = stac_file
+        self.collections = collections
         self.item_collection = item_collection
         self.pages = pages
-        self.message: list = []
+        self.message: List = []
         self.schema = custom
         self.links = links
         self.assets = assets
@@ -68,7 +71,7 @@ class StacValidate:
         self.max_depth = max_depth
         self.extensions = extensions
         self.core = core
-        self.stac_content: dict = {}
+        self.stac_content: Dict = {}
         self.version = ""
         self.depth: int = 0
         self.skip_val = False
@@ -76,7 +79,7 @@ class StacValidate:
         self.valid = False
         self.log = log
 
-    def create_err_msg(self, err_type: str, err_msg: str) -> dict:
+    def create_err_msg(self, err_type: str, err_msg: str) -> Dict:
         self.valid = False
         return {
             "version": self.version,
@@ -99,7 +102,7 @@ class StacValidate:
             "request_invalid": request_invalid,
         }
 
-    def create_message(self, stac_type: str, val_type: str) -> dict:
+    def create_message(self, stac_type: str, val_type: str) -> Dict:
         return {
             "version": self.version,
             "path": self.stac_file,
@@ -109,7 +112,7 @@ class StacValidate:
             "validation_method": val_type,
         }
 
-    def assets_validator(self) -> dict:
+    def assets_validator(self) -> Dict:
         """Validate assets.
 
         Returns:
@@ -122,7 +125,7 @@ class StacValidate:
                 link_request(asset, initial_message)
         return initial_message
 
-    def links_validator(self) -> dict:
+    def links_validator(self) -> Dict:
         """Validate links.
 
         Returns:
@@ -143,7 +146,7 @@ class StacValidate:
 
         return initial_message
 
-    def extensions_validator(self, stac_type: str) -> dict:
+    def extensions_validator(self, stac_type: str) -> Dict:
         """Validate the STAC extensions according to their corresponding JSON schemas.
 
         Args:
@@ -253,7 +256,7 @@ class StacValidate:
         self.schema = set_schema_addr(self.version, stac_type)
         self.custom_validator()
 
-    def default_validator(self, stac_type: str) -> dict:
+    def default_validator(self, stac_type: str) -> Dict:
         """Validate the STAC catalog or item against the core schema and its extensions.
 
         Args:
@@ -379,7 +382,7 @@ class StacValidate:
         self.stac_content = stac_content
         return self.run()
 
-    def validate_item_collection_dict(self, item_collection: dict) -> None:
+    def validate_item_collection_dict(self, item_collection: Dict) -> None:
         """Validate the contents of an item collection.
 
         Args:
@@ -392,6 +395,27 @@ class StacValidate:
             self.schema = ""
             self.validate_dict(item)
 
+    def validate_collections(self) -> None:
+        """ "Validate STAC collections from a /collections endpoint.
+
+        Raises:
+            URLError: If there is an issue with the URL used to fetch the item collection.
+            JSONDecodeError: If the item collection content cannot be parsed as JSON.
+            ValueError: If the item collection does not conform to the STAC specification.
+            TypeError: If the item collection content is not a dictionary or JSON object.
+            FileNotFoundError: If the item collection file cannot be found.
+            ConnectionError: If there is an issue with the internet connection used to fetch the item collection.
+            exceptions.SSLError: If there is an issue with the SSL connection used to fetch the item collection.
+            OSError: If there is an issue with the file system (e.g., read/write permissions) while trying to write to the log file.
+
+        Returns:
+            None
+        """
+        collections = fetch_and_parse_file(str(self.stac_file))
+        for collection in collections["collections"]:
+            self.schema = ""
+            self.validate_dict(collection)
+
     def validate_item_collection(self) -> None:
         """Validate a STAC item collection.
 
@@ -429,9 +453,9 @@ class StacValidate:
                                 break
         except Exception as e:
             message = {}
-            message[
-                "pagination_error"
-            ] = f"Validating the item collection failed on page {page}: {str(e)}"
+            message["pagination_error"] = (
+                f"Validating the item collection failed on page {page}: {str(e)}"
+            )
             self.message.append(message)
 
     def run(self) -> bool:
@@ -457,7 +481,11 @@ class StacValidate:
         """
         message = {}
         try:
-            if self.stac_file is not None and not self.item_collection:
+            if (
+                self.stac_file is not None
+                and not self.item_collection
+                and not self.collections
+            ):
                 self.stac_content = fetch_and_parse_file(self.stac_file)
 
             stac_type = get_stac_type(self.stac_content).upper()
